==> Paws-0.28.tar.gz: Paws-0.28/lib/Paws/CognitoIdp/ForgetDevice.pm <==

package Paws::CognitoIdp::ForgetDevice;
  use Moose;
  has AccessToken => (is => 'ro', isa => 'Str');
  has DeviceKey => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'ForgetDevice');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CognitoIdp::ForgetDevice - Arguments for method ForgetDevice on Paws::CognitoIdp

=head1 DESCRIPTION

This class represents the parameters used for calling the method ForgetDevice on the 
Amazon Cognito Identity Provider service. Use the attributes of this class
as arguments to method ForgetDevice.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to ForgetDevice.

As an example:

  $service_obj->ForgetDevice(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 AccessToken => Str

The access token for the forgotten device request.



=head2 B<REQUIRED> DeviceKey => Str

The device key.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method ForgetDevice in L<Paws::CognitoIdp>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.30.tar.gz: Paws-0.30/lib/Paws/CognitoIdp/ForgetDevice.pm <==

package Paws::CognitoIdp::ForgetDevice;
  use Moose;
  has AccessToken => (is => 'ro', isa => 'Str');
  has DeviceKey => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'ForgetDevice');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CognitoIdp::ForgetDevice - Arguments for method ForgetDevice on Paws::CognitoIdp

=head1 DESCRIPTION

This class represents the parameters used for calling the method ForgetDevice on the 
Amazon Cognito Identity Provider service. Use the attributes of this class
as arguments to method ForgetDevice.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to ForgetDevice.

As an example:

  $service_obj->ForgetDevice(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 AccessToken => Str

The access token for the forgotten device request.



=head2 B<REQUIRED> DeviceKey => Str

The device key.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method ForgetDevice in L<Paws::CognitoIdp>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
